@@ -290,7 +290,7 @@ phases:
     "environment": {
         "type": "LINUX_CONTAINER",
         "image": "nitor/ndt:latest",
-        "computeType": "BUILD_GENERAL1_SMALL",
+        "computeType": "{compute_type}",
         "environmentVariables": [],
         "privilegedMode": true,
         "imagePullCredentialsType": "SERVICE_ROLE"
@@ -392,6 +392,12 @@ phases:
                 ndt_version = subcomponent["properties"]["NDT_VERSION"]
             component_args["environment"]["image"] = "nitor/ndt:"  + ndt_version
 
+            #Setup build environment
+            if "BUILD_ENVIRONMENT_COMPUTE" in subcomponent["properties"]:
+                component_args["environment"]["computeType"] = subcomponent["properties"]["BUILD_ENVIRONMENT_COMPUTE"]
+            else:
+                component_args["environment"]["computeType"] = "BUILD_GENERAL1_SMALL"
+
             # Setup source
             if "CODEBUILD_SOURCE_TYPE" in subcomponent["properties"]:
                 component_args["source"]["type"] = subcomponent["properties"]["CODEBUILD_SOURCE_TYPE"]
@@ -415,6 +421,9 @@ phases:
             else:
                 del component_args["source"]
 
+            if "CODEBUILD_TIMEOUT" in subcomponent["properties"]:
+                component_args["timeoutInMinutes"] = int(subcomponent["properties"]["CODEBUILD_TIMEOUT"])
+
             # Make sure that builds that need docker, start docker
             if "NEEDS_DOCKER" in subcomponent["properties"] and subcomponent["properties"]["NEEDS_DOCKER"] == "y" and "phases" in interpolated_build_spec:
                 start_docker_found = False
@@ -433,15 +442,22 @@ phases:
                     if "commands" not in phase:
                         phase["commands"] = []
                     phase["commands"].insert(0, "start-docker.sh")
-
+                    component_args["source"]["buildspec"] = yaml_save(interpolated_build_spec)
             # Set up webhook filter
             for flter in webhook_args["filterGroups"][0]:
                 if flter["type"] == "FILE_PATH":
                     flter["pattern"] = subcomponent_dir + "/.*"
-                if flter["type"] == "BASE_REF":
-                    flter["pattern"] = "^refs/heads/" + branch + "$"
-                if flter["type"] == "EVENT" and "CODEBUILD_EVENT_FILTER" in subcomponent["properties"]:
-                    flter["pattern"] = subcomponent["properties"]["CODEBUILD_EVENT_FILTER"]
+                if "CODEBUILD_EVENT_FILTER" in subcomponent["properties"] and subcomponent["properties"]["CODEBUILD_EVENT_FILTER"] == "PUSH":
+                    if flter["type"] == "BASE_REF":
+                        flter["type"] = "HEAD_REF"
+                        flter["pattern"] = "^refs/heads/" + branch + "$"
+                    if flter["type"] == "EVENT":
+                        flter["pattern"] = "PUSH"
+                else:
+                    if flter["type"] == "BASE_REF":
+                        flter["pattern"] = "^refs/heads/" + branch + "$"
+                    if flter["type"] == "EVENT" and "CODEBUILD_EVENT_FILTER" in subcomponent["properties"]:
+                        flter["pattern"] = subcomponent["properties"]["CODEBUILD_EVENT_FILTER"]
             webhook_args["projectName"] = component_args['name']
 
             # Run update
